/*
** init_cgu.h
**
** Initialize CGU programmatically
**
** Copyright (c) 2011-2012 Analog Devices, Inc. All Rights Reserved.
**/

#ifndef __INIT_CGU_H__
#define __INIT_CGU_H__

#include "device.h"

/* PLL Multiplier and Divisor Selections (Required Value, Bit Position) */
#ifdef CCLK_SCLK_240_96

  #define DF_VAL     ((1 << BITP_CGU_CTL_DF)      & BITM_CGU_CTL_DF)
  #define MSEL_VAL   ((32 << BITP_CGU_CTL_MSEL)   & BITM_CGU_CTL_MSEL)
  #define CSEL_VAL   ((2  << BITP_CGU_DIV_CSEL)   & BITM_CGU_DIV_CSEL)
  #define SYSSEL_VAL ((5  << BITP_CGU_DIV_SYSSEL) & BITM_CGU_DIV_SYSSEL)
  #define DSEL_VAL   ((8  << BITP_CGU_DIV_DSEL)  & BITM_CGU_DIV_DSEL)

#endif

#ifdef CCLK_SCLK_225_100

  #define DF_VAL     ((0 << BITP_CGU_CTL_DF)      & BITM_CGU_CTL_DF)
  #define MSEL_VAL   ((30 << BITP_CGU_CTL_MSEL)   & BITM_CGU_CTL_MSEL)
  #define CSEL_VAL   ((4  << BITP_CGU_DIV_CSEL)   & BITM_CGU_DIV_CSEL)
  #define SYSSEL_VAL ((9  << BITP_CGU_DIV_SYSSEL) & BITM_CGU_DIV_SYSSEL)
  #define DSEL_VAL   ((15  << BITP_CGU_DIV_DSEL)  & BITM_CGU_DIV_DSEL)

#endif

#ifdef CCLK_SCLK_200_100

  #define DF_VAL     ((0 << BITP_CGU_CTL_DF)      & BITM_CGU_CTL_DF)
  #define MSEL_VAL   ((20 << BITP_CGU_CTL_MSEL)   & BITM_CGU_CTL_MSEL)
  #define CSEL_VAL   ((3  << BITP_CGU_DIV_CSEL)   & BITM_CGU_DIV_CSEL)
  #define SYSSEL_VAL ((6  << BITP_CGU_DIV_SYSSEL) & BITM_CGU_DIV_SYSSEL)
  #define DSEL_VAL   ((10  << BITP_CGU_DIV_DSEL)  & BITM_CGU_DIV_DSEL)

#endif

#ifdef CCLK_SCLK_240_80

  #define DF_VAL     ((1 << BITP_CGU_CTL_DF)      & BITM_CGU_CTL_DF)
  #define MSEL_VAL   ((32 << BITP_CGU_CTL_MSEL)   & BITM_CGU_CTL_MSEL)
  #define CSEL_VAL   ((2  << BITP_CGU_DIV_CSEL)   & BITM_CGU_DIV_CSEL)
  #define SYSSEL_VAL ((6  << BITP_CGU_DIV_SYSSEL) & BITM_CGU_DIV_SYSSEL)
  #define DSEL_VAL   ((8  << BITP_CGU_DIV_DSEL)  & BITM_CGU_DIV_DSEL)

#endif

#define S0SEL_VAL  ((2  << BITP_CGU_DIV_S0SEL)  & BITM_CGU_DIV_S0SEL)
#define OSEL_VAL   ((10  << BITP_CGU_DIV_OSEL)  & BITM_CGU_DIV_OSEL)
#define CLKOUTSEL_VAL   ((4  << BITP_CGU_CLKOUTSEL_CLKOUTSEL)  & BITM_CGU_CLKOUTSEL_CLKOUTSEL)
#define USBCLKSEL_VAL   ((4  << BITP_CGU_CLKOUTSEL_USBCLKSEL)  & BITM_CGU_CLKOUTSEL_USBCLKSEL)


#define HODF            ((21 << BITP_CGU_OSCWDCTL_HODF) & BITM_CGU_OSCWDCTL_HODF)
#define BOUF            ((4 << BITP_CGU_OSCWDCTL_BOUF) & BITM_CGU_OSCWDCTL_BOUF)


typedef enum {
  INIT_CGU_RESULT_SUCCESS,
  INIT_CGU_RESULT_FAILURE,
  INIT_CGU_RESULT_LOCK_ERR,
} INIT_CGU_RESULT;

__ramfunc INIT_CGU_RESULT init_cgu(void);

#endif /* __INIT_CGU_H_ */
